@@ -3,3 +3,5 @@ from .regression import ape, mape, mae, rmse, r2_score, gini, smape, regression_
 from .visualize import plot, plot_gain, plot_lift, plot_qini, plot_tmlegain, plot_tmleqini # noqa
 from .visualize import get_cumgain, get_cumlift, get_qini, get_tmlegain, get_tmleqini # noqa
 from .visualize import auuc_score, qini_score # noqa
+from .sensitivity import Sensitivity, SensitivityPlaceboTreatment # noqa
+from .sensitivity import SensitivityRandomCause, SensitivityRandomReplace, SensitivitySubsetData, SensitivitySelectionBias # noqa
